@@ -31,14 +31,22 @@ from kfinance.client.meta_classes import (
     DelegatedCompanyFunctionsMetaClass,
 )
 from kfinance.client.models.date_and_period_models import (
+    CurrentPeriod,
+    LatestAnnualPeriod,
     LatestPeriods,
+    LatestQuarterlyPeriod,
     Periodicity,
     YearAndQuarter,
 )
 from kfinance.client.server_thread import ServerThread
 from kfinance.domains.companies.company_models import IdentificationTriple
 from kfinance.domains.earnings.earning_models import EarningsCall, TranscriptComponent
-from kfinance.domains.prices.price_models import HistoryMetadata, PriceHistory
+from kfinance.domains.mergers_and_acquisitions.merger_and_acquisition_models import (
+    MergerConsideration,
+    MergerInfo,
+    MergerTimelineElement,
+)
+from kfinance.domains.prices.price_models import HistoryMetadataResp, PriceHistory
 
 
 if TYPE_CHECKING:
@@ -78,7 +86,7 @@ class TradingItem:
         self.trading_item_id = trading_item_id
 
         self._ticker: str | None = None
-        self._history_metadata: HistoryMetadata | None = None
+        self._history_metadata: HistoryMetadataResp | None = None
 
     def __str__(self) -> str:
         """String representation for the company object"""
@@ -105,20 +113,15 @@ class TradingItem:
         return trading_item
 
     @property
-    def history_metadata(self) -> HistoryMetadata:
+    def history_metadata(self) -> HistoryMetadataResp:
         """Get information about exchange and quotation
 
         :return: A dict containing data about the currency, symbol, exchange, type of instrument, and the first trading date
         :rtype: HistoryMetadata
         """
         if self._history_metadata is None:
-            metadata = self.kfinance_api_client.fetch_history_metadata(self.trading_item_id)
-            self._history_metadata = HistoryMetadata(
-                currency=metadata["currency"],
-                symbol=metadata["symbol"],
-                exchange_name=metadata["exchange_name"],
-                instrument_type=metadata["instrument_type"],
-                first_trade_date=datetime.strptime(metadata["first_trade_date"], "%Y-%m-%d").date(),
+            self._history_metadata = self.kfinance_api_client.fetch_history_metadata(
+                self.trading_item_id
             )
         return self._history_metadata
 
@@ -129,7 +132,7 @@ class TradingItem:
         :return: The exchange code of the trading item.
         :rtype: str
         """
-        return self.history_metadata["exchange_name"]
+        return self.history_metadata.exchange_name
 
     def history(
         self,
@@ -635,7 +638,7 @@ class Company(CompanyFunctionsMetaClass):
         if self._mergers_for_company is None:
             mergers_for_company = self.kfinance_api_client.fetch_mergers_for_company(
                 company_id=self.company_id
-            )
+            ).model_dump(mode="json")
             output: dict = {}
             for literal in ["target", "buyer", "seller"]:
                 output[literal] = MergersAndAcquisitions(
@@ -872,7 +875,7 @@ class Ticker(DelegatedCompanyFunctionsMetaClass):
         self._primary_security: Security | None = None
         self._primary_trading_item: TradingItem | None = None
         self._company: Company | None = None
-        self._history_metadata: HistoryMetadata | None = None
+        self._history_metadata: HistoryMetadataResp | None = None
 
     @property
     def id_triple(self) -> IdentificationTriple:
@@ -946,6 +949,8 @@ class Ticker(DelegatedCompanyFunctionsMetaClass):
         :return: the CIQ security id
         :rtype: int
         """
+        if self.id_triple.security_id is None:
+            raise ValueError(f"Ticker {self.ticker} does not have a security_id.")
         return self.id_triple.security_id
 
     @property
@@ -955,6 +960,8 @@ class Ticker(DelegatedCompanyFunctionsMetaClass):
         :return: the CIQ trading item id
         :rtype: int
         """
+        if self.id_triple.trading_item_id is None:
+            raise ValueError(f"Ticker {self.ticker} does not have a trading_item_id.")
         return self.id_triple.trading_item_id
 
     @property
@@ -1158,7 +1165,7 @@ class Ticker(DelegatedCompanyFunctionsMetaClass):
         return self.company.earnings_call_datetimes
 
     @property
-    def history_metadata(self) -> HistoryMetadata:
+    def history_metadata(self) -> HistoryMetadataResp:
         """Get information about exchange and quotation
 
         :return: A dict containing data about the currency, symbol, exchange, type of instrument, and the first trading date
@@ -1166,9 +1173,9 @@ class Ticker(DelegatedCompanyFunctionsMetaClass):
         """
         metadata = self.primary_trading_item.history_metadata
         if self.exchange_code is None:
-            self.exchange_code = metadata["exchange_name"]
+            self.exchange_code = metadata.exchange_name
         if self._ticker is None:
-            self._ticker = metadata["symbol"]
+            self._ticker = metadata.symbol
         return metadata
 
     @property
@@ -1176,7 +1183,7 @@ class Ticker(DelegatedCompanyFunctionsMetaClass):
         """Get the ticker if it isn't available from initialization"""
         if self._ticker is not None:
             return self._ticker
-        return self.history_metadata["symbol"]
+        return self.history_metadata.symbol
 
     def history(
         self,
@@ -1267,24 +1274,13 @@ class MergerOrAcquisition:
         self.transaction_id = transaction_id
         self.merger_title = merger_title
         self.closed_date = closed_date
-        self._merger_info: dict | None = None
+        self._merger_info: MergerInfo | None = None
 
     @property
-    def merger_info(self) -> dict:
+    def merger_info(self) -> MergerInfo:
         """Property for the combined information in the merger."""
         if not self._merger_info:
             self._merger_info = self.kfinance_api_client.fetch_merger_info(self.transaction_id)
-            if "timeline" in self._merger_info and self._merger_info["timeline"]:
-                timeline = pd.DataFrame(self._merger_info["timeline"])
-                timeline["date"] = pd.to_datetime(timeline["date"])
-                self._merger_info["timeline"] = timeline
-            if (
-                "consideration" in self._merger_info
-                and self._merger_info["consideration"]
-                and "details" in self._merger_info["consideration"]
-            ):
-                details = pd.DataFrame(self._merger_info["consideration"]["details"])
-                self._merger_info["consideration"]["details"] = details
         return self._merger_info
 
     @property
@@ -1293,9 +1289,9 @@ class MergerOrAcquisition:
         return self.merger_title
 
     @property
-    def get_timeline(self) -> pd.DataFrame:
+    def get_timeline(self) -> list[MergerTimelineElement]:
         """The timeline of the merger includes every new status, along with the dates of each status change."""
-        return self.merger_info["timeline"]
+        return self.merger_info.timeline
 
     @property
     def get_participants(self) -> dict:
@@ -1309,8 +1305,8 @@ class MergerOrAcquisition:
                 transaction_id=self.transaction_id,
                 company=Company(
                     kfinance_api_client=self.kfinance_api_client,
-                    company_id=self.merger_info["participants"]["target"]["company_id"],
-                    company_name=self.merger_info["participants"]["target"]["company_name"],
+                    company_id=self.merger_info.participants.target.company_id,
+                    company_name=self.merger_info.participants.target.company_name,
                 ),
             ),
             "buyers": [
@@ -1319,11 +1315,11 @@ class MergerOrAcquisition:
                     transaction_id=self.transaction_id,
                     company=Company(
                         kfinance_api_client=self.kfinance_api_client,
-                        company_id=company["company_id"],
-                        company_name=company["company_name"],
+                        company_id=company.company_id,
+                        company_name=company.company_name,
                     ),
                 )
-                for company in self.merger_info["participants"]["buyers"]
+                for company in self.merger_info.participants.buyers
             ],
             "sellers": [
                 ParticipantInMerger(
@@ -1331,16 +1327,16 @@ class MergerOrAcquisition:
                     transaction_id=self.transaction_id,
                     company=Company(
                         kfinance_api_client=self.kfinance_api_client,
-                        company_id=company["company_id"],
-                        company_name=company["company_name"],
+                        company_id=company.company_id,
+                        company_name=company.company_name,
                     ),
                 )
-                for company in self.merger_info["participants"]["sellers"]
+                for company in self.merger_info.participants.sellers
             ],
         }
 
     @property
-    def get_consideration(self) -> dict:
+    def get_consideration(self) -> MergerConsideration:
         """A merger's consideration is the assets exchanged for the target company.
 
         Properties in the consideration include:
@@ -1355,7 +1351,7 @@ class MergerOrAcquisition:
                 - The number of shares in the target company.
                 - The current gross total of the consideration detail.
         """
-        return self.merger_info["consideration"]
+        return self.merger_info.consideration
 
 
 @add_methods_of_singular_class_to_iterable_class(Company)
@@ -1870,7 +1866,7 @@ class Client:
         """
         mergers_for_company = self.kfinance_api_client.fetch_mergers_for_company(
             company_id=company_id
-        )
+        ).model_dump(mode="json")
         output: dict = {}
         for literal in ["target", "buyer", "seller"]:
             output[literal] = MergersAndAcquisitions(
@@ -1904,16 +1900,18 @@ class Client:
         most_recent_year_annual = current_year - 1
 
         current_month = datetime_now.month
-        latest: LatestPeriods = {
-            "annual": {"latest_year": most_recent_year_annual},
-            "quarterly": {"latest_quarter": most_recent_qtr, "latest_year": most_recent_year_qtrly},
-            "now": {
-                "current_year": current_year,
-                "current_quarter": current_qtr,
-                "current_month": current_month,
-                "current_date": datetime_now.date().isoformat(),
-            },
-        }
+        latest = LatestPeriods(
+            annual=LatestAnnualPeriod(latest_year=most_recent_year_annual),
+            quarterly=LatestQuarterlyPeriod(
+                latest_quarter=most_recent_qtr, latest_year=most_recent_year_qtrly
+            ),
+            now=CurrentPeriod(
+                current_year=current_year,
+                current_quarter=current_qtr,
+                current_month=current_month,
+                current_date=datetime_now.date(),
+            ),
+        )
         return latest
 
     @staticmethod
@@ -1933,9 +1931,9 @@ class Client:
         year_n_quarters_ago = total_quarters_completed_n_quarters_ago // 4
         quarter_n_quarters_ago = total_quarters_completed_n_quarters_ago % 4 + 1
 
-        year_quarter_n_quarters_ago: YearAndQuarter = {
-            "year": year_n_quarters_ago,
-            "quarter": quarter_n_quarters_ago,
-        }
+        year_quarter_n_quarters_ago = YearAndQuarter(
+            year=year_n_quarters_ago,
+            quarter=quarter_n_quarters_ago,
+        )
 
         return year_quarter_n_quarters_ago
