@@ -7,10 +7,13 @@ from kfinance.client.kfinance import Client
 from kfinance.conftest import SPGI_COMPANY_ID
 from kfinance.domains.earnings.earning_tools import (
     GetEarningsFromIdentifiers,
+    GetEarningsFromIdentifiersResp,
     GetLatestEarningsFromIdentifiers,
     GetNextEarningsFromIdentifiers,
+    GetNextOrLatestEarningsFromIdentifiersResp,
     GetTranscriptFromKeyDevId,
     GetTranscriptFromKeyDevIdArgs,
+    GetTranscriptFromKeyDevIdResp,
 )
 from kfinance.integrations.tool_calling.tool_calling_models import ToolArgsWithIdentifiers
 
@@ -43,27 +46,29 @@ class TestGetEarnings:
             json=self.earnings_response,
         )
 
-        expected_response = {
-            "results": {
-                "SPGI": {
-                    "earnings_calls": [
-                        {
-                            "name": "SPGI Q1 2025 Earnings Call",
-                            "key_dev_id": 12346,
-                            "datetime": "2025-04-29T12:30:00Z",
-                        },
-                        {
-                            "name": "SPGI Q4 2024 Earnings Call",
-                            "key_dev_id": 12345,
-                            "datetime": "2025-02-11T13:30:00Z",
-                        },
-                    ]
-                }
-            },
-            "errors": [
-                "No identification triple found for the provided identifier: NON-EXISTENT of type: ticker"
-            ],
-        }
+        expected_response = GetEarningsFromIdentifiersResp.model_validate(
+            {
+                "results": {
+                    "SPGI": {
+                        "earnings": [
+                            {
+                                "name": "SPGI Q1 2025 Earnings Call",
+                                "key_dev_id": 12346,
+                                "datetime": "2025-04-29T12:30:00Z",
+                            },
+                            {
+                                "name": "SPGI Q4 2024 Earnings Call",
+                                "key_dev_id": 12345,
+                                "datetime": "2025-02-11T13:30:00Z",
+                            },
+                        ]
+                    }
+                },
+                "errors": [
+                    "No identification triple found for the provided identifier: NON-EXISTENT of type: ticker"
+                ],
+            }
+        )
 
         tool = GetEarningsFromIdentifiers(kfinance_client=mock_client)
         response = tool.run(
@@ -95,16 +100,18 @@ class TestGetEarnings:
             json={"earnings": []},
         )
 
-        expected_response = {
-            "results": {
-                "SPGI": {
-                    "name": "SPGI Q1 2025 Earnings Call",
-                    "key_dev_id": 12346,
-                    "datetime": "2025-04-29T12:30:00Z",
-                }
-            },
-            "errors": ["No latest earnings available for private_company."],
-        }
+        expected_response = GetNextOrLatestEarningsFromIdentifiersResp.model_validate(
+            {
+                "results": {
+                    "SPGI": {
+                        "name": "SPGI Q1 2025 Earnings Call",
+                        "key_dev_id": 12346,
+                        "datetime": "2025-04-29T12:30:00Z",
+                    }
+                },
+                "errors": ["No latest earnings available for private_company."],
+            }
+        )
 
         tool = GetLatestEarningsFromIdentifiers(kfinance_client=mock_client)
         response = tool.run(
@@ -136,16 +143,18 @@ class TestGetEarnings:
             json={"earnings": []},
         )
 
-        expected_response = {
-            "results": {
-                "SPGI": {
-                    "datetime": "2025-04-29T12:30:00Z",
-                    "key_dev_id": 12346,
-                    "name": "SPGI Q1 2025 Earnings Call",
-                }
-            },
-            "errors": ["No next earnings available for private_company."],
-        }
+        expected_response = GetNextOrLatestEarningsFromIdentifiersResp.model_validate(
+            {
+                "results": {
+                    "SPGI": {
+                        "datetime": "2025-04-29T12:30:00Z",
+                        "key_dev_id": 12346,
+                        "name": "SPGI Q1 2025 Earnings Call",
+                    }
+                },
+                "errors": ["No next earnings available for private_company."],
+            }
+        )
 
         tool = GetNextEarningsFromIdentifiers(kfinance_client=mock_client)
         response = tool.run(
@@ -181,8 +190,8 @@ class TestGetTranscript:
             json=transcript_data,
         )
 
-        expected_response = (
-            "Operator: Good morning, everyone.\n\nCEO: Thank you for joining us today."
+        expected_response = GetTranscriptFromKeyDevIdResp(
+            transcript="Operator: Good morning, everyone.\n\nCEO: Thank you for joining us today."
         )
 
         tool = GetTranscriptFromKeyDevId(kfinance_client=mock_client)
