@@ -1,6 +1,13 @@
+from decimal import Decimal
 from itertools import chain
 from typing import TypedDict
 
+from pydantic import BaseModel
+
+
+class LineItemResponse(BaseModel):
+    line_item: dict[str, Decimal | None]
+
 
 class LineItemType(TypedDict):
     name: str
@@ -1592,6 +1599,127 @@ LINE_ITEMS: list[LineItemType] = [
         "dataitemid": 4034,
         "spgi_name": "Total Debt/Equity",
     },
+    {
+        "name": "last_close_tev_to_ebit",
+        "aliases": {
+            "ev_to_ebit",
+            "enterprise_value_to_ebit",
+            "enterprise_value_to_earnings_before_interest_and_taxes",
+            "tev_to_ebit",
+            "total_ev_to_ebit",
+            "total_enterprise_value_to_ebit",
+            "total_enterprise_value_to_earnings_before_interest_and_taxes",
+            "last_tev_to_ebit",
+            "last_total_ev_to_ebit",
+            "last_enterprise_value_to_ebit",
+            "last_enterprise_value_to_earnings_before_interest_and_taxes",
+            "last_total_enterprise_value_to_ebit",
+            "last_total_enterprise_value_to_earnings_before_interest_and_taxes",
+            "last_close_ev_to_ebit",
+            "last_close_enterprise_value_to_ebit",
+            "last_close_total_ev_to_ebit",
+            "last_close_enterprise_value_to_ebit",
+            "last_close_enterprise_value_to_earnings_before_interest_and_taxes",
+            "last_close_total_enterprise_value_to_ebit",
+            "last_close_total_enterprise_value_to_earnings_before_interest_and_taxes",
+        },
+        "dataitemid": 100062,
+        "spgi_name": "Last Close TEV / EBIT",
+    },
+    {
+        "name": "last_close_tev_to_ebitda",
+        "aliases": {
+            "ev_to_ebitda",
+            "enterprise_value_to_ebitda",
+            "enterprise_value_to_earnings_before_interest_taxes_depreciation_and_amortization",
+            "tev_to_ebitda",
+            "total_ev_to_ebitda",
+            "total_enterprise_value_to_ebitda",
+            "total_enterprise_value_to_earnings_before_interest_taxes_depreciation_and_amortization",
+            "last_tev_to_ebitda",
+            "last_total_ev_to_ebitda",
+            "last_enterprise_value_to_ebitda",
+            "last_enterprise_value_to_earnings_before_interest_taxes_depreciation_and_amortization",
+            "last_total_enterprise_value_to_ebitda",
+            "last_total_enterprise_value_to_earnings_before_interest_taxes_depreciation_and_amortization",
+            "last_close_total_ev_to_ebitda",
+            "last_close_enterprise_value_to_ebitda",
+            "last_close_enterprise_value_to_earnings_before_interest_taxes_depreciation_and_amortization",
+            "last_close_total_enterprise_value_to_ebitda",
+            "last_close_total_enterprise_value_to_earnings_before_interest_taxes_depreciation_and_amortization",
+        },
+        "dataitemid": 100063,
+        "spgi_name": "Last Close TEV / EBITDA",
+    },
+    {
+        "name": "ev_to_employees",
+        "aliases": {
+            "ev_to_employee_count",
+            "ev_to_headcount",
+            "enterprise_value_to_employees",
+            "enterprise_value_to_employee_count",
+            "enterprise_value_to_headcount",
+            "tev_to_employees",
+            "tev_to_employee_count",
+            "tev_to_headcount",
+            "total_ev_to_employees",
+            "total_ev_to_employee_count",
+            "total_ev_to_headcount",
+            "total_enterprise_value_to_employees",
+            "total_enterprise_value_to_employee_count",
+            "total_enterprise_value_to_headcount",
+            "last_ev_to_employees",
+            "last_ev_to_employee_count",
+            "last_ev_to_headcount",
+            "last_tev_to_employees",
+            "last_tev_to_employee_count",
+            "last_tev_to_headcount",
+            "last_total_ev_to_employees",
+            "last_total_ev_to_employee_count",
+            "last_total_ev_to_headcount",
+            "last_enterprise_value_to_employees",
+            "last_enterprise_value_to_employee_count",
+            "last_enterprise_value_to_headcount",
+            "last_total_enterprise_value_to_employees",
+            "last_total_enterprise_value_to_employee_count",
+            "last_total_enterprise_value_to_headcount",
+            "last_close_ev_to_employees",
+            "last_close_ev_to_employee_count",
+            "last_close_ev_to_headcount",
+            "last_close_tev_to_employees",
+            "last_close_tev_to_employee_count",
+            "last_close_tev_to_headcount",
+            "last_close_total_ev_to_employees",
+            "last_close_total_ev_to_employee_count",
+            "last_close_total_ev_to_headcount",
+            "last_close_enterprise_value_to_employees",
+            "last_close_enterprise_value_to_employee_count",
+            "last_close_enterprise_value_to_headcount",
+            "last_close_total_enterprise_value_to_employees",
+            "last_close_total_enterprise_value_to_employee_count",
+            "last_close_total_enterprise_value_to_headcount",
+        },
+        "dataitemid": 100070,
+        "spgi_name": "Last Close TEV / Employees",
+    },
+    {
+        "name": "ev_to_total_revenue",
+        "aliases": {
+            "tev_to_total_revenue",
+            "enterprise_value_to_total_revenue",
+            "total_enterprise_value_to_total_revenue",
+            "last_ev_to_total_revenue",
+            "last_tev_to_total_revenue",
+            "last_enterprise_value_to_total_revenue",
+            "last_enterprise_value_to_total_revenue",
+            "last_close_ev_to_total_revenue",
+            "last_close_tev_to_total_revenue",
+            "last_close_enterprise_value_to_total_revenue",
+            "last_close_enterprise_value_to_total_revenue",
+        },
+        "dataitemid": 100061,
+        "spgi_name": "Last Close TEV / Total Revenue",
+    },
 ]
 LINE_ITEM_NAMES_AND_ALIASES: list[str] = list(
     chain(*[[line_item["name"]] + list(line_item["aliases"]) for line_item in LINE_ITEMS])
