@@ -14,6 +14,7 @@ from kfinance.integrations.tool_calling.tool_calling_models import (
     KfinanceTool,
     ToolArgsWithIdentifiers,
     ToolRespWithErrors,
+    ValidQuarter,
 )
 
 
@@ -27,8 +28,8 @@ class GetFinancialLineItemFromIdentifiersArgs(ToolArgsWithIdentifiers):
     period_type: PeriodType | None = Field(default=None, description="The period type")
     start_year: int | None = Field(default=None, description="The starting year for the data range")
     end_year: int | None = Field(default=None, description="The ending year for the data range")
-    start_quarter: Literal[1, 2, 3, 4] | None = Field(default=None, description="Starting quarter")
-    end_quarter: Literal[1, 2, 3, 4] | None = Field(default=None, description="Ending quarter")
+    start_quarter: ValidQuarter | None = Field(default=None, description="Starting quarter")
+    end_quarter: ValidQuarter | None = Field(default=None, description="Ending quarter")
 
 
 class GetFinancialLineItemFromIdentifiersResp(ToolRespWithErrors):
@@ -42,6 +43,7 @@ class GetFinancialLineItemFromIdentifiers(KfinanceTool):
 
         - When possible, pass multiple identifiers in a single call rather than making multiple calls.
         - To fetch the most recent value for the line item, leave start_year, start_quarter, end_year, and end_quarter as None.
+        - The tool accepts arguments in calendar years, and all outputs will be presented in terms of calendar years. Please note that these calendar years may not align with the company's fiscal year.
 
         Example:
         Query: "What are the revenues of Lowe's and Home Depot?"
@@ -62,7 +64,7 @@ class GetFinancialLineItemFromIdentifiers(KfinanceTool):
         end_year: int | None = None,
         start_quarter: Literal[1, 2, 3, 4] | None = None,
         end_quarter: Literal[1, 2, 3, 4] | None = None,
-    ) -> dict:
+    ) -> GetFinancialLineItemFromIdentifiersResp:
         """Sample response:
 
         {
@@ -108,11 +110,11 @@ class GetFinancialLineItemFromIdentifiers(KfinanceTool):
             and len(line_item_responses) > 1
         ):
             for line_item_response in line_item_responses.values():
-                most_recent_year = max(line_item_response.line_item.keys())
-                most_recent_year_data = line_item_response.line_item[most_recent_year]
-                line_item_response.line_item = {most_recent_year: most_recent_year_data}
+                if line_item_response.line_item:
+                    most_recent_year = max(line_item_response.line_item.keys())
+                    most_recent_year_data = line_item_response.line_item[most_recent_year]
+                    line_item_response.line_item = {most_recent_year: most_recent_year_data}
 
-        output_model = GetFinancialLineItemFromIdentifiersResp(
+        return GetFinancialLineItemFromIdentifiersResp(
             results=line_item_responses, errors=list(id_triple_resp.errors.values())
         )
-        return output_model.model_dump(mode="json")
