@@ -1,3 +1,4 @@
+from textwrap import dedent
 from typing import Literal, Type
 
 from pydantic import BaseModel, Field
@@ -30,7 +31,11 @@ class GetSegmentsFromIdentifiersResp(ToolRespWithErrors):
 
 class GetSegmentsFromIdentifiers(KfinanceTool):
     name: str = "get_segments_from_identifiers"
-    description: str = "Get the templated segments associated with a list of identifiers."
+    description: str = dedent("""
+        Get the templated segments associated with a list of identifiers.
+
+        - The tool accepts arguments in calendar years, and all outputs will be presented in terms of calendar years. Please note that these calendar years may not align with the company's fiscal year.
+    """).strip()
     args_schema: Type[BaseModel] = GetSegmentsFromIdentifiersArgs
     accepted_permissions: set[Permission] | None = {Permission.SegmentsPermission}
 
@@ -43,7 +48,7 @@ class GetSegmentsFromIdentifiers(KfinanceTool):
         end_year: int | None = None,
         start_quarter: Literal[1, 2, 3, 4] | None = None,
         end_quarter: Literal[1, 2, 3, 4] | None = None,
-    ) -> dict:
+    ) -> GetSegmentsFromIdentifiersResp:
         """Sample Response:
 
         {
@@ -98,11 +103,11 @@ class GetSegmentsFromIdentifiers(KfinanceTool):
             and len(segments_responses) > 1
         ):
             for segments_response in segments_responses.values():
-                most_recent_year = max(segments_response.segments.keys())
-                most_recent_year_data = segments_response.segments[most_recent_year]
-                segments_response.segments = {most_recent_year: most_recent_year_data}
+                if segments_response.segments:
+                    most_recent_year = max(segments_response.segments.keys())
+                    most_recent_year_data = segments_response.segments[most_recent_year]
+                    segments_response.segments = {most_recent_year: most_recent_year_data}
 
-        output_model = GetSegmentsFromIdentifiersResp(
+        return GetSegmentsFromIdentifiersResp(
             results=segments_responses, errors=list(id_triple_resp.errors.values())
         )
-        return output_model.model_dump(mode="json")
