@@ -1,3 +1,6 @@
+from typing import Any
+
+from pydantic import BaseModel
 from strenum import StrEnum
 
 
@@ -7,3 +10,7 @@ class StatementType(StrEnum):
     balance_sheet = "balance_sheet"
     income_statement = "income_statement"
     cashflow = "cashflow"
+
+
+class StatementsResp(BaseModel):
+    statements: dict[str, Any]
