@@ -11,6 +11,7 @@ from kfinance.integrations.tool_calling.tool_calling_models import (
     KfinanceTool,
     ToolArgsWithIdentifiers,
     ToolRespWithErrors,
+    ValidQuarter,
 )
 
 
@@ -20,8 +21,8 @@ class GetFinancialStatementFromIdentifiersArgs(ToolArgsWithIdentifiers):
     period_type: PeriodType | None = Field(default=None, description="The period type")
     start_year: int | None = Field(default=None, description="The starting year for the data range")
     end_year: int | None = Field(default=None, description="The ending year for the data range")
-    start_quarter: Literal[1, 2, 3, 4] | None = Field(default=None, description="Starting quarter")
-    end_quarter: Literal[1, 2, 3, 4] | None = Field(default=None, description="Ending quarter")
+    start_quarter: ValidQuarter | None = Field(default=None, description="Starting quarter")
+    end_quarter: ValidQuarter | None = Field(default=None, description="Ending quarter")
 
 
 class GetFinancialStatementFromIdentifiersResp(ToolRespWithErrors):
@@ -34,6 +35,7 @@ class GetFinancialStatementFromIdentifiers(KfinanceTool):
         Get a financial statement associated with a group of identifiers.
 
         - To fetch the most recent value for the statement, leave start_year, start_quarter, end_year, and end_quarter as None.
+        - The tool accepts arguments in calendar years, and all outputs will be presented in terms of calendar years. Please note that these calendar years may not align with the company's fiscal year.
 
         Example:
         Query: "Fetch the balance sheets of BAC and GS for 2024"
@@ -54,7 +56,7 @@ class GetFinancialStatementFromIdentifiers(KfinanceTool):
         end_year: int | None = None,
         start_quarter: Literal[1, 2, 3, 4] | None = None,
         end_quarter: Literal[1, 2, 3, 4] | None = None,
-    ) -> dict:
+    ) -> GetFinancialStatementFromIdentifiersResp:
         """Sample response:
 
         {
@@ -104,11 +106,11 @@ class GetFinancialStatementFromIdentifiers(KfinanceTool):
             and len(statement_responses) > 1
         ):
             for statement_response in statement_responses.values():
-                most_recent_year = max(statement_response.statements.keys())
-                most_recent_year_data = statement_response.statements[most_recent_year]
-                statement_response.statements = {most_recent_year: most_recent_year_data}
+                if statement_response.statements:
+                    most_recent_year = max(statement_response.statements.keys())
+                    most_recent_year_data = statement_response.statements[most_recent_year]
+                    statement_response.statements = {most_recent_year: most_recent_year_data}
 
-        output_model = GetFinancialStatementFromIdentifiersResp(
+        return GetFinancialStatementFromIdentifiersResp(
             results=statement_responses, errors=list(id_triple_resp.errors.values())
         )
-        return output_model.model_dump(mode="json")
