@@ -7,7 +7,11 @@ from requests_mock import Mocker
 
 from kfinance.client.kfinance import Client
 from kfinance.conftest import SPGI_COMPANY_ID
-from kfinance.domains.companies.company_tools import GetInfoFromIdentifiers
+from kfinance.domains.companies.company_models import COMPANY_ID_PREFIX
+from kfinance.domains.companies.company_tools import (
+    GetInfoFromIdentifiers,
+    GetInfoFromIdentifiersResp,
+)
 from kfinance.integrations.tool_calling.tool_calling_models import ValidQuarter
 
 
@@ -22,13 +26,20 @@ class TestGetEndpointsFromToolCallsWithGrounding:
         """
 
         # truncated from the original
-        resp_data = {"name": "S&P Global Inc.", "status": "Operating"}
+        resp_data = {
+            "name": "S&P Global Inc.",
+            "status": "Operating",
+            "company_id": f"{COMPANY_ID_PREFIX}{SPGI_COMPANY_ID}",
+        }
         resp_endpoint = [
             "https://kfinance.kensho.com/api/v1/ids",
             "https://kfinance.kensho.com/api/v1/info/21719",
         ]
-        expected_resp = {"data": {"results": {"SPGI": resp_data}}, "endpoint_urls": resp_endpoint}
-
+        expected_resp = {
+            "data": GetInfoFromIdentifiersResp.model_validate({"results": {"SPGI": resp_data}}),
+            "endpoint_urls": resp_endpoint,
+        }
+        del resp_data["company_id"]
         requests_mock.get(
             url=f"https://kfinance.kensho.com/api/v1/info/{SPGI_COMPANY_ID}",
             json=resp_data,
